@@ -422,7 +422,8 @@ class Workflow(CacheableBase):
             output = {}
 
             if not result:
-                return output
+                self.errors = {}
+                return {}
 
             for stepName, stepData in result['result'][0].get(self.workflowName, {}).items():
                 errors = {}
